@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store::SQL;
-our $VERSION = '1.20210927';
+our $VERSION = '1.20211209';
 use strict;
 use warnings;
 
@@ -141,13 +141,13 @@ sub delete_report {
     if (scalar @row_ids) {
         foreach my $table (qw/ report_record_spf report_record_dkim report_record_reason /) {
             print "deleting $table rows " . join(',', @row_ids) . "\n" if $self->verbose;
-            eval { $self->query( $self->grammar->delete_from_where_record_in($table, \@row_ids)); };
+            eval { $self->query( $self->grammar->delete_from_where_record_in($table), \@row_ids); };
             # warn $@ if $@;
         }
     }
     foreach my $table (qw/ report_policy_published report_record report_error /) {
         print "deleting $table rows for report $report_id\n" if $self->verbose;
-        eval { $self->query( $self->grammar->delete_from_where_report( $table, [$report_id] )); };
+        eval { $self->query( $self->grammar->delete_from_where_report($table), [$report_id] ); };
         # warn $@ if $@;
     }
 
@@ -682,7 +682,7 @@ Mail::DMARC::Report::Store::SQL - store and retrieve reports from a SQL RDBMS
 
 =head1 VERSION
 
-version 1.20210927
+version 1.20211209
 
 =head1 DESCRIPTION
 
